package Prty::Mojolicious::Plugin::Log::Parameters;
use base qw/Mojolicious::Plugin/;

use strict;
use warnings;

# -----------------------------------------------------------------------------

=encoding utf8

=head1 NAME

Prty::Mojolicious::Plugin::Log::Parameters - Logge Request-Parameter

=head1 BASE CLASS

Mojolicious::Plugin

=head1 SYNOPSIS

    # Mojolicious
    $app->plugin('Prty::Mojolicious::Plugin::Log::Parameters');
    
    # Mojolicious::Lite
    plugin 'Prty::Mojolicious::Plugin::Log::Parameters';

=head1 DESCRIPTION

Das Plugin installiert einen C<before_routes> Handler, der bei
jedem Request die Liste der empfangenen GET- und POST-Parameter
ins Log ausgibt. Loglevel ist C<debug>.

Das Plugin ist bei der Entwicklung von Action-Seiten zu Formularen
nützlich, denn es macht sichtbar, welche Daten die Action-Seite
empfängt.

=head1 METHODS

=head2 register() - Registriere Plugin

=head3 Synopsis

    $plugin->register($app,$conf);

=head3 Description

Diese Methode implementiert die Funktionalität des Plugin. Sie
wird nicht direkt aufgerufen, sondern indirekt durch Aufruf der
Methode $app->plugin().

=cut

# -----------------------------------------------------------------------------

sub register {
    my ($self,$app,$conf) = @_;

    $app->hook(before_routes=>sub {
        my $c = shift;

        my $p = $c->req->params;
        for my $key (sort @{$p->names}) {
            my $valA = $p->every_param($key);
            $c->app->log->debug(
                "Param: $key => ".join ',',map {qq|"$_"|} @$valA);
        }
    });

    return;
}

# -----------------------------------------------------------------------------

=head1 AUTHOR

Frank Seitz, L<http://fseitz.de/>

=cut

# -----------------------------------------------------------------------------

1;

# eof
